==> wiki3_5_6dev1.zip: wiki3_5_6dev1/plugin/comment/Comment.pm <==
############################################################
# 
# <p>ԥȤ񤭹िΥեϤޤ</p>
# <pre>
# {{comment}}
# </pre>
# <p>
#   ̾ȤƥեβɲäƤޤ
#   ץǥեξ˿ɽ褦ˤǤޤ
# </p>
# <pre>
# {{comment reverse}}
# </pre>
# <p>
#   tailץĤȥڡκǸ˥Ȥɲäޤ
#   եåʤɤcommentץ饰֤ڡ˥Ȥ
#   ĤͭǤ
# </p>
# <pre>
# {{comment tail}}
# </pre>
# 
############################################################
package plugin::comment::Comment;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ȥե
#===========================================================
sub paragraph {
	my $self = shift;
	my $wiki = shift;
	my $opt  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $page = $cgi->param("page");
	
	if(!defined($self->{$page})){
		$self->{$page} = 1;
	} else {
		$self->{$page}++;
	}
	
	# åѤʤΤ̾
	my $name = '';
	unless($wiki->use_cache($page)){
		$name = $cgi->cookie(-name=>'post_name');
		if($name eq ''){
			my $login = $wiki->get_login_info();
			if(defined($login)){
				$name = $login->{id};
			}
		}
	}
	
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/comment.tmpl",
	                               die_on_bad_params=>0);
	$tmpl->param(NAME=>$name);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output().
	          "<input type=\"hidden\" name=\"action\" value=\"COMMENT\">\n".
	          "<input type=\"hidden\" name=\"page\" value=\"".&Util::escapeHTML($page)."\">\n".
	          "<input type=\"hidden\" name=\"count\" value=\"".$self->{$page}."\">\n".
	          "<input type=\"hidden\" name=\"option\" value=\"".&Util::escapeHTML($opt)."\">\n".
	          "</form>\n";
	
	return $buf;
}

1;

==> wiki3_6_0.zip: wiki3_6_0/plugin/comment/Comment.pm <==
############################################################
# 
# <p>ԥȤ񤭹िΥեϤޤ</p>
# <pre>
# {{comment}}
# </pre>
# <p>
#   ̾ȤƥեβɲäƤޤ
#   ץǥեξ˿ɽ褦ˤǤޤ
# </p>
# <pre>
# {{comment reverse}}
# </pre>
# <p>
#   tailץĤȥڡκǸ˥Ȥɲäޤ
#   եåʤɤcommentץ饰֤ڡ˥Ȥ
#   ĤͭǤ
# </p>
# <pre>
# {{comment tail}}
# </pre>
# 
############################################################
package plugin::comment::Comment;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ȥե
#===========================================================
sub paragraph {
	my $self = shift;
	my $wiki = shift;
	my $opt  = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $page = $cgi->param("page");
	
	if(!defined($self->{$page})){
		$self->{$page} = 1;
	} else {
		$self->{$page}++;
	}
	
	# ̾
	my $name = $cgi->cookie(-name=>'post_name');
	if($name eq ''){
		my $login = $wiki->get_login_info();
		if(defined($login)){
			$name = $login->{id};
		}
	}
	
	my $tmpl = HTML::Template->new(filename=>$wiki->config('tmpl_dir')."/comment.tmpl",
	                               die_on_bad_params=>0);
	$tmpl->param(NAME=>$name);
	
	my $buf = "<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	          $tmpl->output().
	          "<input type=\"hidden\" name=\"action\" value=\"COMMENT\">\n".
	          "<input type=\"hidden\" name=\"page\" value=\"".&Util::escapeHTML($page)."\">\n".
	          "<input type=\"hidden\" name=\"count\" value=\"".$self->{$page}."\">\n".
	          "<input type=\"hidden\" name=\"option\" value=\"".&Util::escapeHTML($opt)."\">\n".
	          "</form>\n";
	
	return $buf;
}

1;
